summaryrefslogtreecommitdiff
path: root/src/jit/compiler.hpp
diff options
context:
space:
mode:
authorMike Danes <onemihaid@hotmail.com>2018-06-16 16:45:02 +0300
committerMike Danes <onemihaid@hotmail.com>2018-06-30 22:31:19 +0300
commit9ca3690ab2f7828cc46c84a8a55de04d3d9667aa (patch)
tree96ea9d378ce6cfa0833e97f2760382e188f303a5 /src/jit/compiler.hpp
parente39f1d837342c41ddc34a49de2dbcf8f5b664ad9 (diff)
downloadcoreclr-9ca3690ab2f7828cc46c84a8a55de04d3d9667aa.tar.gz
coreclr-9ca3690ab2f7828cc46c84a8a55de04d3d9667aa.tar.bz2
coreclr-9ca3690ab2f7828cc46c84a8a55de04d3d9667aa.zip
Move temp info from Compiler to RegSet
Temporaries are only used during register allocation and code generation. They waste space (136 bytes) in the compiler object during inlining.
Diffstat (limited to 'src/jit/compiler.hpp')
-rw-r--r--src/jit/compiler.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/jit/compiler.hpp b/src/jit/compiler.hpp
index d873eadaa8..7ae64603d7 100644
--- a/src/jit/compiler.hpp
+++ b/src/jit/compiler.hpp
@@ -2354,11 +2354,11 @@ inline
FPbased = isFramePointerUsed();
if (lvaDoneFrameLayout == Compiler::FINAL_FRAME_LAYOUT)
{
- TempDsc* tmpDsc = tmpFindNum(varNum);
+ TempDsc* tmpDsc = codeGen->regSet.tmpFindNum(varNum);
// The temp might be in use, since this might be during code generation.
if (tmpDsc == nullptr)
{
- tmpDsc = tmpFindNum(varNum, Compiler::TEMP_USAGE_USED);
+ tmpDsc = codeGen->regSet.tmpFindNum(varNum, RegSet::TEMP_USAGE_USED);
}
assert(tmpDsc != nullptr);
offset = tmpDsc->tdTempOffs();
@@ -3063,7 +3063,7 @@ XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
/*****************************************************************************/
/* static */ inline unsigned Compiler::tmpSlot(unsigned size)
{
noway_assert(size >= sizeof(int));
noway_assert(size <= TEMP_MAX_SIZE);
@@ -3079,10 +3079,10 @@ XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
* over a function body.
*/
-inline void Compiler::tmpEnd()
+inline void RegSet::tmpEnd()
{
#ifdef DEBUG
- if (verbose && (tmpCount > 0))
+ if (m_rsCompiler->verbose && (tmpCount > 0))
{
printf("%d tmps used\n", tmpCount);
}
@@ -3095,7 +3095,7 @@ inline void Compiler::tmpEnd()
* compiled.
*/
-inline void Compiler::tmpDone()
+inline void RegSet::tmpDone()
{
#ifdef DEBUG
unsigned count;
@@ -3063,7 +3063,7 @@ XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
/*****************************************************************************/
-/* static */ inline unsigned Compiler::tmpSlot(unsigned size)
+/* static */ inline unsigned RegSet::tmpSlot(unsigned size)
{
noway_assert(size >= sizeof(int));